@@ -11,17 +11,19 @@ from fastai import *
 
 class RAWPYobj:
     "This is to copy class Image.Image but actually support RAW image files"
-    def __init__(self, fn: Path, pr: rawpy.Params):
-        # exposure=findall('[a-zA-Z]+',fn.parents[0].name)[0] # Retrieces "Long" or "Short" exposure
-        fn = str(fn)
+    def __init__(self,fn:Path,pr:rawpy.Params,output_bps=8):
+        #exposure=findall('[a-zA-Z]+',fn.parents[0].name)[0] # Retrieces "Long" or "Short" exposure
+        self.output_bps=output_bps
+        fn=str(fn)
         try:
             with rawpy.imread(fn) as RAWobj:
-                self.obj = RAWobj
-                self.ndarr = np.array(RAWobj.postprocess(pr)).astype(np.float32)
-                self._size = self.ndarr.shape[:2]
-                self.mode = "RGB" if self.ndarr.shape[2] == 3 else self.ndarr.shape[2]
+                self.obj=RAWobj
+                self.ndarr=np.array(RAWobj.postprocess(pr)).astype(np.float32)
+                self._size=self.ndarr.shape[:2]
+                self.num_colors=RAWobj.num_colors
+                self.mode="RGB" if self.ndarr.shape[2]==3 else self.ndarr.shape[2]
         except rawpy._rawpy.LibRawIOError:
-            print("Error. LibRawIOError: This file didn't open: --- ", fn)
+            print("Error. LibRawIOError: This file didn't open: --- ",fn)
 
     def Update_Size(self):
         self._size = self.ndarr.shape[:2]
@@ -47,9 +49,9 @@ class RAWImage(RAWPYobj):
     "basic Image class made of Rawpy"
 
     @classmethod
-    def create(cls, fn: Path, pr: rawpy.Params) -> None:
-        # print("RAWImage.create(): pr", pr)
-        return cls(fn, pr)
+    def create(cls,fn:Path,pr:rawpy.Params,output_bps)->None:
+        #print("RAWImage.create(): pr", pr)
+        return cls(fn,pr,output_bps)
 
     def __repr__(
             self): return f'{self.__class__.__name__} mode={self.mode} size={"x".join([str(d) for d in self.size])}'
